.. include:: ../README.rst

Contents
========

.. toctree::
   :maxdepth: 2

   Getting Started <getting_started>
   Concept <concept>
   Developing `smif` <developers>
   Contributing <contributing>
   License <license>
   Authors <authors>
   Changelog <changes>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
